@@ -1,9 +1,9 @@
 /* 
  * gnome-print-pango.c
  *
- * Copyright (C) 2003
+ * Copyright (C) 2003-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@
 #define GTK_TEXT_USE_INTERNAL_UNSUPPORTED_API
 #include <gtk/gtktextlayout.h>
 #include "gnome-print-pango.h"
+#include <string.h>
 
 #ifdef GP_HAS_PANGO
 #	include <libgnomeprint/gnome-print-pango.h>
