@@ -238,6 +238,9 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 		}
 	}
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
+	m_pView->Update (this);
+	Update ();
+	m_pView->EnsureSize ();
 	return true;
 }
 
@@ -572,12 +575,15 @@ bool gcpDocument::Load(xmlNodePtr root)
 	}
 	m_bIsLoading = false;
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
+	m_pView->EnsureSize ();
+	Update ();
 	return true;
 }
 	
 void gcpDocument::ParseXMLTree(xmlDocPtr xml)
 {
 	Load(xml->children);
+	g_signal_emit_by_name (GetWidget (), "update_bounds");
 }
 
 xmlDocPtr gcpDocument::BuildXMLTree()
@@ -850,6 +856,7 @@ void gcpDocument::OnUndo()
 		ActivateMenu(EditMenu, UndoMenu, false);
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
+	Update ();
 }
 
 void gcpDocument::OnRedo()
@@ -868,6 +875,7 @@ void gcpDocument::OnRedo()
 		ActivateMenu(EditMenu, RedoMenu, false);
 	ActivateMenu (FileMenu, SaveAsImageMenu, HasChildren ());
 	m_bUndoRedo = false;
+	Update ();
 }
 
 void gcpDocument::FinishOperation()
