@@ -206,6 +206,7 @@ void on_print(GtkWidget* widget, void* data)
 	int do_preview, copies = 1, collate = 0;
 	GnomePrintDialog *gpd;
 	gpd = GNOME_PRINT_DIALOG (gnome_print_dialog_new(gpj, (const guchar*)_("Print"), GNOME_PRINT_DIALOG_COPIES));
+	SET_ICON (gpd);
 	gnome_print_dialog_set_copies(gpd, copies, collate);
 	switch (gtk_dialog_run(GTK_DIALOG(gpd)))
 	{
@@ -230,7 +231,9 @@ void on_print(GtkWidget* widget, void* data)
 	gnome_print_job_close(gpj);
 	if (do_preview)
 	{
-		gtk_widget_show (gnome_print_job_preview_new (gpj, (const guchar*)_("Preview")));
+		GtkWidget *preview = gnome_print_job_preview_new (gpj, (const guchar*)_("Preview"));
+		SET_ICON (preview);
+		gtk_widget_show (preview);
 	}
 	else
 	{
@@ -407,18 +410,15 @@ void on_about(GtkWidget* widget, void* data)
 {
 	char * authors[]={"Jean Bréfort",NULL};
 	char * documentors[] = {NULL};
-	char * translators = _(\
-"Jean Bréfort <jean.brefort@ac-dijon.fr>: French\n\
-Christian Neumair <christian-neumair@web.de>: German\n\
-Costantino Ceoldo: Italian\n\
-Ben Luo: Chinese\n\
-Michał Sałaban: Polish"
-			);
 	GdkPixbuf* pixbuf = gdk_pixbuf_new_from_file ( DATADIR"/"PACKAGE"/pixmaps/gchempaint_logo.png", NULL);
+	char *translator_credits = _("translator_credits");
 	GtkWidget* about = gnome_about_new(_("GChemPaint"), VERSION,
 										_("(C) 2001-2004 by Jean Bréfort"),
 										_("GChemPaint is a 2D chemical structures editor for Gnome"),
-										(const gchar**) authors, (const gchar**) documentors, translators, pixbuf);
+										(const gchar**) authors, (const gchar**) documentors,
+										(strcmp (translator_credits, "translator_credits") != 0 ? 
+											(const char *)translator_credits : NULL),
+										pixbuf);
 	SET_ICON(about);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
